/*
 * Copyright 2011 Goldman Sachs.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.gs.collections.impl.collection.mutable;

import java.io.Externalizable;
import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;

import com.gs.collections.api.collection.MutableCollection;

public class SynchronizedCollectionSerializationProxy<T> implements Externalizable
{
    private static final long serialVersionUID = 1L;

    private MutableCollection<T> mutableCollection;

    @SuppressWarnings("UnusedDeclaration")
    public SynchronizedCollectionSerializationProxy()
    {
        // Empty constructor for Externalizable class
    }

    public SynchronizedCollectionSerializationProxy(MutableCollection<T> collection)
    {
        this.mutableCollection = collection;
    }

    public void writeExternal(ObjectOutput out) throws IOException
    {
        out.writeObject(this.mutableCollection);
    }

    public void readExternal(ObjectInput in) throws IOException, ClassNotFoundException
    {
        this.mutableCollection = (MutableCollection<T>) in.readObject();
    }

    protected Object readResolve()
    {
        return this.mutableCollection.asSynchronized();
    }
}
